Module constraint

Module constraint 

Core constraint types.

This module provides fundamental constraint identification and classification types used throughout the constraint evaluation system.

Structs

ConstraintRef
Reference to a constraint for identification.

Enums

ImpactType
Type of impact a constraint has on the score.