Re-exports
pub use listener::ListVariableListener;pub use listener::ListVariableNotification;pub use listener::VariableListener;pub use listener::VariableNotification;pub use supply::AnchorSupply;pub use supply::ElementPosition;pub use supply::InverseSupply;pub use supply::ListStateSupply;
Modules
Structs
- Chained
Variable Info - Computed
Value Range Provider - A value range provider that computes values dynamically.
- Dynamic
List Access Capabilities - Object-safe dynamic list variable access.
- Dynamic
List Metadata Capabilities - Immutable capabilities bound to one dynamic planning-list slot.
- Dynamic
List Variable Slot - Public dynamic list variable slot.
- Dynamic
Scalar Assignment Metadata Capabilities - Structural capabilities supplied by a dynamic scalar-assignment group.
- Dynamic
Scalar Variable Slot - Public dynamic scalar variable slot.
- Entity
Class Id - Logical planning-entity class identifier.
- Entity
Collection Extractor - A concrete entity extractor for a specific solution and entity type.
- Entity
Descriptor - Describes a planning entity type at runtime.
- Entity
Ref - Field
Value Range Provider - A value range provider backed by a field in the solution.
- Integer
Range - An integer range value provider.
- Problem
Fact Class Id - Logical problem-fact class identifier.
- Problem
Fact Descriptor - Describes a problem fact type at runtime.
- Solution
Descriptor - Describes a planning solution at runtime.
- Static
Value Range - A static value range with a fixed set of values.
- Variable
Descriptor - Variable
Id - Logical planning-variable identifier.
Enums
Traits
- Dynamic
List Access - Dynamic
List Metadata - Slot-bound immutable metadata used by canonical dynamic-list phases.
- Dynamic
Model Backend - Rust-owned dynamic planning model backend.
- Dynamic
Scalar Access - Object-safe dynamic scalar variable access.
- Dynamic
Scalar Assignment Metadata - Object-safe metadata access for one dynamic scalar-assignment group.
- Entity
Extractor - Trait for extracting entities from a planning solution.
- List
Variable Solution - Trait for solutions with list-based planning variables.
- Planning
Entity - Marker trait for planning entities.
- Planning
Id - Trait for unique identification of entities and facts.
- Planning
Solution - Marker trait for planning solutions.
- Problem
Fact - Marker trait for problem facts.
- Value
Range Provider - Provides values for a planning variable.